@@ -105,6 +105,30 @@ def play(obj, name, service_id, output):
         p.play(output)
 
 
+@cmd.command()
+@click.argument(
+    'obj',
+    type=click.Choice(['media']),
+    metavar='media'
+    )
+@click.argument(
+    'name',
+    type=click.Choice([('media')]),
+    metavar='MEDIA_NAME'
+    )
+def is_scheduled(obj, name):
+    """Verifier si un fichier est déja programmé ou pas"""
+    if obj == 'media':
+        tsfile = media.Media(name)
+        result = tsfile.schedule()
+        if result:
+            click.echo("\nCe Fichier est déja programmé: {}".format(result))
+        elif result == {}:
+            click.echo("\nCe Fichier est libre")
+    else:
+        click.echo("\nargument non défini")
+
+
 @cmd.command()
 @click.argument(
     'obj',
@@ -116,8 +140,9 @@ def play(obj, name, service_id, output):
     metavar='MEDIA_NAME_OR_PROGRAM_DATE'
     )
 def delete(obj, name):
-    """Suppression d'un media ou d'un programme. \                                                                                                                        
-    Le nom d'un programme est sa date de diffusion au format jjmmaaaa.                                                                                                    
+    """
+    Suppression d'un media ou d'un programme.
+    Le nom d'un programme est sa date de diffusion au format jjmmaaaa.
     """
     if obj == 'media':
         tsfile = media.Media(name)
@@ -132,7 +157,7 @@ def delete(obj, name):
             'location': tsfile.filepath,
             'duration': tsfile.duration,
             'schedule': {}
-            }    
+            }
         click.echo('Location: {}'.format(result['location']))
         click.echo('Duration: {}'.format(result['duration']))
         bar = {}
