@@ -401,7 +401,19 @@ class Media(object):
         elif schedule == {}:
             print("j'efface: {}".format(self.filepath))
             if os.path.exists(self.filepath):
-                os.remove(self.filepath)
+                try:
+                    # verifier si c'est un lien symbolink
+                    # si oui effacer également la source
+                    source_file = os.readlink(path)
+                    os.remove(self.filepath)
+                    os.remove(source_file)
+                except OSError as err:
+                    os.remove(self.filepath)
+                    print("{} n'est pas un lien symbolique: {}".format(
+                        self.filepath,
+                        err
+                        )
+                        )
             else:
                 print("{} n'existes pas".format(self.filepath))
         return
